@@ -4,7 +4,7 @@ import (
 	"os"
 	"testing"
 
-	"github.com/goreleaser/goreleaser/internal/testlib"
+	"github.com/goreleaser/goreleaser/v2/internal/testlib"
 	"github.com/stretchr/testify/require"
 )
 
@@ -62,14 +62,14 @@ func goModInit(tb testing.TB) {
 	tb.Helper()
 	createFile(tb, "go.mod", `module foo
 
-go 1.21
+go 1.22
 `)
 }
 
 func createGoReleaserYaml(tb testing.TB) {
 	tb.Helper()
-	yaml := `build:
-  binary: fake
+	yaml := `builds:
+- binary: fake
   goos:
     - linux
   goarch:
