@@ -12,10 +12,10 @@ import (
 
 	"code.gitea.io/sdk/gitea"
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 type giteaClient struct {
@@ -51,7 +51,7 @@ func newGitea(ctx *context.Context, token string) (*giteaClient, error) {
 	transport := &http.Transport{
 		Proxy: http.ProxyFromEnvironment,
 		TLSClientConfig: &tls.Config{
-			// nolint: gosec
+			//nolint:gosec
 			InsecureSkipVerify: ctx.Config.GiteaURLs.SkipTLSVerify,
 		},
 	}
