@@ -12,12 +12,12 @@ import (
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/semerrgroup"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const (
@@ -34,11 +34,12 @@ type asset struct {
 
 type assetOpenFunc func(string, *artifact.Artifact) (*asset, error)
 
-// nolint: gochecknoglobals
+//nolint:gochecknoglobals
 var assetOpen assetOpenFunc
 
 // TODO: fix this.
-// nolint: gochecknoinits
+//
+//nolint:gochecknoinits
 func init() {
 	assetOpenReset()
 }
@@ -156,7 +157,6 @@ type ResponseChecker func(*h.Response) error
 func Upload(ctx *context.Context, uploads []config.Upload, kind string, check ResponseChecker) error {
 	// Handle every configured upload
 	for _, upload := range uploads {
-		upload := upload
 		filters := []artifact.Filter{}
 		if upload.Checksum {
 			filters = append(filters, artifact.ByType(artifact.Checksum))
@@ -206,7 +206,6 @@ func uploadWithFilter(ctx *context.Context, upload *config.Upload, filter artifa
 	log.Debugf("will upload %d artifacts", len(artifacts))
 	g := semerrgroup.New(ctx.Parallelism)
 	for _, artifact := range artifacts {
-		artifact := artifact
 		g.Go(func() error {
 			return uploadAsset(ctx, upload, artifact, kind, check)
 		})
